2014 Gstaad: A Small World With Carey Mulligan | Hot Topics | Grazia Daily
Description: From fondue-ing at the top of a mountain to hanging with Carey Mulligan, we round up the highlights of ASMALLWORLD's winter weekend.
Keywords: a small world, gstaad, palace, winter weekend, carey mulligan, dianna agron, pixie geldof, jeremy irvine, tali lennox,

Search

# Inside Our Trip To Gstaad With A Small World And Carey Mulligan

By Alya Mooro - 19 December 2014

Contributing Writer

Carey Mulligan and Dianna Agron at ASW Winter Weekend [Rex]

'Tis the season to wrap up, get glam and ingest your body weight in food and drink. No better time, then, for ASMALLWORLD's utterly fabulous multi-day 10th birthday party in Gstaad, Switzerland. And so it was that our Alya Mooro joined a rolodex of some of the most alluring individuals, the likes of Dianna Agron, Caitlin FitzGerald, Pixie Geldof, Tali Lennox and the utterly charming Carey Mulligan - who hosted the Saturday night charity gala in aid of War Child - to descend upon the Palace Hotel in Gstaad for a weekend that positively oozed glamour. We round up some of our highlights of the trip below...

## Eating & Drinking... Lots

Our Alya Mooro with ASMALLWORLD guest at the cocktail dinner

The Palace Hotel acted as ground zero for the weekend, hosting a number of fabulous gatherings including welcome cocktails on the Friday night ahead of an epic dinner at in-house restaurant Gildo's where guests got to know each other over wine and three courses of superb cuisine before decamping to the basement club (more on which later).

## Gstaad'd From The Bottom...

The view from the top of Wasserngrat

While some of the more ambitious of individuals spent their morning after the night before taking to the slopes in their ski gear, the rest of us took a more leisurely approach in the form of a chairlift to the top of Wasserngrat mountain, where we were greeted by a beaming sun, ridiculously Instagrammable views and cauldrons and cauldrons of bubbling cheese. And our lives were basically complete. Giddy from having ingested a lifetime supply of cheese and wine, the remainder of the afternoon was spent concoting the best hashtags to accompany our fairytale-perfect snaps. Our favourite? 'Gstaad'd from the bottom now we here.' Yup, we think Drake would be proud of that one, too. All credit to the altitude. And the wine.

## Reckless & Generous...

Paula Goldstein, Cleo Wade, Caitlin Fitzgerald rocking the headgear at ASW Winter Weekend [Rex]

Snow boots and gigantic fluffy hats safely tucked away, guests descended upon the Palace ballroom in a dizzying array of black tie extravagance. With trailing dresses in any and all colours imaginable, glittering jewels and a collection of headdresses that frankly make Blair Waldorf's look preeeetty pitiful, guests took their seats for a five course meal that was overseen by none other than Carey Mulligan and ASW Chairman Patrick Liotard-Vogt. 'I am begging you to give recklessly and generously,' said Mulligan in her impassioned address. And who could turn her down? With help from raffle prizes from the likes of Hublot, Maiyet, Tinker Tailor, and even a peck on the cheek from Dianna Agron, $100,000 was raised for War Child - a charity that provides support to children in high conflict zones around the world.

## Take It To The Basement...

Our Alya Mooro with Dianna Agron

The Palace's basement nightclub - hailed as one of the most exclusive in the region - hosted the afterparties that concluded both festive evenings, and almost contributed to many a missed flight on the Sunday morning! Shoes in hand and fists pumping, attendees of the soirees quite literally let their hair down, dancing into the morning with a little help from the DJs who alternated between the latest in chart topping hits to never forgotten classics, pleasing just about everyone in the process. As attendees from literally all around the world revelled in the moment, we realised just how small a world it is, and how happy we are to be a part of it.

### Tags:

Carey Mulligan

### Share:

## You May Also Like

### Hot Topics

#### Inside Our Trip To Gstaad With A Small World And Carey Mulligan

### Hot Topics

#### Charli XCX Charts The Soundtrack To Her Life

### Hot Topics

#### CONFIRMED: Keira Knightley Is Pregnant

### Fashion

#### 2014 Best Dressed: Rihanna Did The Trends So You Didn't Have To

### Entertainment

#### Wish You Were Here! See The Stars On Their Festive Breaks

### Fashion

#### Best Dressed: Alexa Chung's Boy-Meets-Girl Wardrobe

powered by DISQUS Read more

#### Disqus

Disqus allows you to post comments on our site. You can only post comments if you register with Disqus and your registration data will be handled in accordance with their privacy policy.

Disqus will use your registration data (email) to send you additional information. Details of how you can opt out are contained in the verification email which you will be sent after you sign up

Please read the Disqus terms of service

Loading...

comments powered by Disqus

## Related Stories

### Hot Topics

#### Our Night At The 2014 MTV EMAs With Her Minajesty, Ariana Grande & Co.

### Fashion News

#### 10 Ways To Have A Chic Christmas This Year

### Beauty

#### The Top 10 Beauty Solutions For Skiing and Other Snowy Situations

## Latest Stories

- ### 2 January 2015 Wish You Were Here! See The Stars On Their Festive Breaks

- ### 2 January 2015 VIDEO: Taylor Swift Gives Fans Personalised Presents

- ### 2 January 2015 Joseph Gordon-Levitt Married In A Secret Ceremony

- ### 29 December 2014 "Peaches’ Loss Has Been A Wake-Up Call"

- ### 28 December 2014 Adele Denies Break Up Rumours On Twitter

- ### 28 December 2014 Jennifer Lawrence Was The Top Grossing Actor Of 2014

- ### 28 December 2014 Adele Denies Break Up Rumours On Twitter

- ### 28 December 2014 Jennifer Lawrence Was The Top Grossing Actor Of 2014

- ### 26 December 2014 The Chiltern Firehouse And 7 Other Things That Peaked In 2014

- ### 26 December 2014 An Instagram Insight Into How The Stars Are Celebrating Christmas